Struct U64
#[repr(C)]pub struct U64(pub [u64; 1]);Expand description
Little-endian large integer type Unsigned 64-bit integer.
Tuple Fields
0: [u64; 1]Implementations
impl U64
impl U64
pub fn from_str_radix(txt: &str, radix: u32) -> Result<U64, FromStrRadixErr>
pub fn from_str_radix(txt: &str, radix: u32) -> Result<U64, FromStrRadixErr>
Converts a string slice in a given base to an integer. Only supports radixes of 10 and 16.
pub fn from_dec_str(value: &str) -> Result<U64, FromDecStrErr>
pub fn from_dec_str(value: &str) -> Result<U64, FromDecStrErr>
Convert from a decimal string.
pub fn as_u64(&self) -> u64
pub fn as_u64(&self) -> u64
Conversion to u64 with overflow checking
Panics
Panics if the number is larger than u64::max_value().
pub fn as_usize(&self) -> usize
pub fn as_usize(&self) -> usize
Conversion to usize with overflow checking
Panics
Panics if the number is larger than usize::max_value().
pub fn leading_zeros(&self) -> u32
pub fn leading_zeros(&self) -> u32
Returns the number of leading zeros in the binary representation of self.
pub fn trailing_zeros(&self) -> u32
pub fn trailing_zeros(&self) -> u32
Returns the number of trailing zeros in the binary representation of self.
pub const fn byte(&self, index: usize) -> u8
pub const fn byte(&self, index: usize) -> u8
Return specific byte. Byte 0 is the least significant value (ie~ little endian).
Panics
Panics if index exceeds the byte width of the number.
pub fn to_big_endian(&self) -> [u8; 8]
pub fn to_big_endian(&self) -> [u8; 8]
Convert to big-endian bytes.
pub fn write_as_big_endian(&self, bytes: &mut [u8])
pub fn write_as_big_endian(&self, bytes: &mut [u8])
Write to the slice in big-endian format.
pub fn to_little_endian(&self) -> [u8; 8]
pub fn to_little_endian(&self) -> [u8; 8]
Convert to little-endian bytes.
pub fn write_as_little_endian(&self, bytes: &mut [u8])
pub fn integer_sqrt(&self) -> U64
pub fn integer_sqrt(&self) -> U64
Compute the highest n such that n * n <= self.
pub fn pow(self, expon: U64) -> U64
pub fn pow(self, expon: U64) -> U64
Fast exponentiation by squaring https://en.wikipedia.org/wiki/Exponentiation_by_squaring
Panics
Panics if the result overflows the type.
pub fn overflowing_pow(self, expon: U64) -> (U64, bool)
pub fn overflowing_pow(self, expon: U64) -> (U64, bool)
Fast exponentiation by squaring. Returns result and overflow flag.
pub fn checked_pow(self, expon: U64) -> Option<U64>
pub fn checked_pow(self, expon: U64) -> Option<U64>
Checked exponentiation. Returns None if overflow occurred.
pub fn overflowing_add(self, other: U64) -> (U64, bool)
pub fn overflowing_add(self, other: U64) -> (U64, bool)
Addition which overflows and returns a flag if it does.
pub fn saturating_add(self, other: U64) -> U64
pub fn saturating_add(self, other: U64) -> U64
Addition which saturates at the maximum value (Self::MAX).
pub fn checked_add(self, other: U64) -> Option<U64>
pub fn checked_add(self, other: U64) -> Option<U64>
Checked addition. Returns None if overflow occurred.
pub fn overflowing_sub(self, other: U64) -> (U64, bool)
pub fn overflowing_sub(self, other: U64) -> (U64, bool)
Subtraction which underflows and returns a flag if it does.
pub fn saturating_sub(self, other: U64) -> U64
pub fn saturating_sub(self, other: U64) -> U64
Subtraction which saturates at zero.
pub fn checked_sub(self, other: U64) -> Option<U64>
pub fn checked_sub(self, other: U64) -> Option<U64>
Checked subtraction. Returns None if overflow occurred.
pub fn overflowing_mul(self, other: U64) -> (U64, bool)
pub fn overflowing_mul(self, other: U64) -> (U64, bool)
Multiply with overflow, returning a flag if it does.
pub fn saturating_mul(self, other: U64) -> U64
pub fn saturating_mul(self, other: U64) -> U64
Multiplication which saturates at the maximum value..
pub fn checked_mul(self, other: U64) -> Option<U64>
pub fn checked_mul(self, other: U64) -> Option<U64>
Checked multiplication. Returns None if overflow occurred.
pub fn checked_div(self, other: U64) -> Option<U64>
pub fn checked_div(self, other: U64) -> Option<U64>
Checked division. Returns None if other == 0.
pub fn checked_rem(self, other: U64) -> Option<U64>
pub fn checked_rem(self, other: U64) -> Option<U64>
Checked modulus. Returns None if other == 0.
pub fn overflowing_neg(self) -> (U64, bool)
pub fn overflowing_neg(self) -> (U64, bool)
Negation with overflow.
pub fn checked_neg(self) -> Option<U64>
pub fn checked_neg(self) -> Option<U64>
Checked negation. Returns None unless self == 0.
pub fn from_big_endian(slice: &[u8]) -> U64
pub fn from_big_endian(slice: &[u8]) -> U64
Converts from big endian representation bytes in memory.
pub fn from_little_endian(slice: &[u8]) -> U64
pub fn from_little_endian(slice: &[u8]) -> U64
Converts from little endian representation bytes in memory.